==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ja.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "カレンダー",
    "Todos" : "ToDo",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor}はカレンダー {calendar} を作成しました",
    "You created calendar {calendar}" : "カレンダー {calendar} を作成しました",
    "{actor} deleted calendar {calendar}" : "{actor}はカレンダー {calendar} を削除しました",
    "You deleted calendar {calendar}" : "カレンダー {calendar} を削除しました",
    "{actor} updated calendar {calendar}" : "{actor}はカレンダー {calendar} を更新しました",
    "You updated calendar {calendar}" : "カレンダー {calendar} を更新しました",
    "You shared calendar {calendar} as public link" : "カレンダー{calendar}を公開リンクとして共有しました",
    "You removed public link for calendar {calendar}" : "カレンダー{calendar}の公開リンクを削除しました",
    "{actor} shared calendar {calendar} with you" : "{actor} が カレンダー{calendar} を あなたと共有しました",
    "You shared calendar {calendar} with {user}" : " カレンダー{calendar} を {user} と共有しました",
    "{actor} shared calendar {calendar} with {user}" : "{actor} が カレンダー{calendar} を {user} と共有しました",
    "{actor} unshared calendar {calendar} from you" : "{actor} が あなたからカレンダー{calendar} を共有解除しました",
    "You unshared calendar {calendar} from {user}" : "{user}からカレンダー{calendar} を共有解除しました",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} が  {user} からカレンダー{calendar} を共有解除しました",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}がカレンダー{calendar} を共有解除しました",
    "You shared calendar {calendar} with group {group}" : " カレンダー{calendar} を グループ{group} と共有しました",
    "{actor} shared calendar {calendar} with group {group}" : " {actor}がカレンダー{calendar} を グループ{group} と共有しました",
    "You unshared calendar {calendar} from group {group}" : "グループ{group}からカレンダー{calendar}の共有を解除しました",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}がグループ{group}からカレンダー{calendar}の共有を解除しました",
    "{actor} created event {event} in calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を作成しました",
    "You created event {event} in calendar {calendar}" : "カレンダー {calendar} のイベント{event}を作成しました",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を削除しました",
    "You deleted event {event} from calendar {calendar}" : "カレンダー {calendar} のイベント{event}を削除しました",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を更新しました",
    "You updated event {event} in calendar {calendar}" : "カレンダー {calendar} のイベント{event}を更新しました",
    "Busy" : "ビジー",
    "{actor} created todo {todo} in list {calendar}" : "{actor}はリスト{calendar}のtodo {todo}を作成しました",
    "You created todo {todo} in list {calendar}" : "リスト {calendar} にtodo {todo} を作成しました",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor}リスト{カレンダー}からtodo {todo}を削除しました",
    "You deleted todo {todo} from list {calendar}" : "あなたはtodo {todo}を{calendar}のリストから削除しました。",
    "{actor} updated todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を更新しました",
    "You updated todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を更新しました。",
    "{actor} solved todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を解決しました",
    "You solved todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を解決しました。",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor}リスト{calendar}のToDo {todo}を再開しました",
    "You reopened todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を再開しました",
    "A <strong>calendar</strong> was modified" : "<strong>カレンダー</strong>が変更されたとき",
    "A calendar <strong>event</strong> was modified" : "カレンダーの<strong>イベント</strong>が変更されたとき",
    "A calendar <strong>todo</strong> was modified" : "カレンダーの<strong>ToDo</strong>が変更されたとき",
    "Contact birthdays" : "誕生日",
    "%1$s via %2$s" : "%1$s に %2$s から",
    "Invitation canceled" : "招待のキャンセル",
    "Hello %s," : "%s さん、こんにちは",
    "The meeting »%1$s« with %2$s was canceled." : "会議%1$s « %2$s がキャンセルされました。",
    "Invitation updated" : "招待の更新",
    "The meeting »%1$s« with %2$s was updated." : "会議 %1$s« %2$s が更新されました。",
    "%1$s invited you to »%2$s«" : "%1$s があなたを »%2$s« に招待しました",
    "When:" : "いつ:",
    "Where:" : "場所:",
    "Description:" : "説明:",
    "Link:" : "リンク:",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "More options …" : "他のオプション …",
    "More options at %s" : "%s のその他のオプション",
    "Contacts" : "アドレス帳",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS / macOSでCalDAVおよびCardDAVを使用するには、%sにHTTPSを設定する必要があります。",
    "Configures a CalDAV account" : "CalDAVアカウントを設定します",
    "Configures a CardDAV account" : "CardDAVアカウントを設定します",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAVエンドポイント",
    "Technical details" : "技術的な詳細",
    "Remote Address: %s" : "リモートアドレス: %s",
    "Request ID: %s" : "リクエスト ID: %s",
    "There was an error updating your attendance status." : "出席状況の更新中にエラーが発生しました。",
    "Please contact the organizer directly." : "主催者に直接お問い合わせください。",
    "Are you accepting the invitation?" : "招待を受け入れていますか？",
    "Tentative" : "暫定的",
    "Save" : "保存",
    "Your attendance was updated successfully." : "出席は正常に更新されました。",
    "Calendar server" : "カレンダーサーバー",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "{calendarappstoreopen}カレンダーアプリ{linkclose}、または{calendardocopen}を同期させるためにデスクトップとモバイルを接続する{linkclose}もインストールしてください。",
    "Send invitations to attendees" : "参加者に招待状を送信する",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen}(メールサーバ{linkclose}内)を正しく設定してください。",
    "Automatically generate a birthday calendar" : "自動的に誕生日カレンダーを生成する",
    "Birthday calendars will be generated by a background job." : "誕生日カレンダーは、バックグラウンドジョブによって生成されます。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "したがって、有効にした直後は利用できませんが、しばらくしてから表示されます。",
    "%s via %s" : "%s に %s から",
    "The meeting »%s« with %s was canceled." : "会議 »%s« %sがキャンセルされました。",
    "The meeting »%s« with %s was updated." : "会議 »%s« %sが更新されました。",
    "%s invited you to »%s«" : "%s があなたを »%s« に招待しました",
    "Please make sure to properly set up the email settings above." : "上記のメール設定を正しく設定してください。"
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ja.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "カレンダー",
    "Todos" : "ToDo",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor}はカレンダー {calendar} を作成しました",
    "You created calendar {calendar}" : "カレンダー {calendar} を作成しました",
    "{actor} deleted calendar {calendar}" : "{actor}はカレンダー {calendar} を削除しました",
    "You deleted calendar {calendar}" : "カレンダー {calendar} を削除しました",
    "{actor} updated calendar {calendar}" : "{actor}はカレンダー {calendar} を更新しました",
    "You updated calendar {calendar}" : "カレンダー {calendar} を更新しました",
    "You shared calendar {calendar} as public link" : "カレンダー{calendar}を公開リンクとして共有しました",
    "You removed public link for calendar {calendar}" : "カレンダー{calendar}の公開リンクを削除しました",
    "{actor} shared calendar {calendar} with you" : "{actor} が カレンダー{calendar} を あなたと共有しました",
    "You shared calendar {calendar} with {user}" : " カレンダー{calendar} を {user} と共有しました",
    "{actor} shared calendar {calendar} with {user}" : "{actor} が カレンダー{calendar} を {user} と共有しました",
    "{actor} unshared calendar {calendar} from you" : "{actor} が あなたからカレンダー{calendar} を共有解除しました",
    "You unshared calendar {calendar} from {user}" : "{user}からカレンダー{calendar} を共有解除しました",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} が  {user} からカレンダー{calendar} を共有解除しました",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}がカレンダー{calendar} を共有解除しました",
    "You shared calendar {calendar} with group {group}" : " カレンダー{calendar} を グループ{group} と共有しました",
    "{actor} shared calendar {calendar} with group {group}" : " {actor}がカレンダー{calendar} を グループ{group} と共有しました",
    "You unshared calendar {calendar} from group {group}" : "グループ{group}からカレンダー{calendar}の共有を解除しました",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}がグループ{group}からカレンダー{calendar}の共有を解除しました",
    "{actor} created event {event} in calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を作成しました",
    "You created event {event} in calendar {calendar}" : "カレンダー {calendar} のイベント{event}を作成しました",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を削除しました",
    "You deleted event {event} from calendar {calendar}" : "カレンダー {calendar} のイベント{event}を削除しました",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を更新しました",
    "You updated event {event} in calendar {calendar}" : "カレンダー {calendar} のイベント{event}を更新しました",
    "Busy" : "ビジー",
    "{actor} created todo {todo} in list {calendar}" : "{actor}はリスト{calendar}のtodo {todo}を作成しました",
    "You created todo {todo} in list {calendar}" : "リスト {calendar} にtodo {todo} を作成しました",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor}リスト{カレンダー}からtodo {todo}を削除しました",
    "You deleted todo {todo} from list {calendar}" : "あなたはtodo {todo}を{calendar}のリストから削除しました。",
    "{actor} updated todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を更新しました",
    "You updated todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を更新しました。",
    "{actor} solved todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を解決しました",
    "You solved todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を解決しました。",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor}リスト{calendar}のToDo {todo}を再開しました",
    "You reopened todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を再開しました",
    "A <strong>calendar</strong> was modified" : "<strong>カレンダー</strong>が変更されたとき",
    "A calendar <strong>event</strong> was modified" : "カレンダーの<strong>イベント</strong>が変更されたとき",
    "A calendar <strong>todo</strong> was modified" : "カレンダーの<strong>ToDo</strong>が変更されたとき",
    "Death of %s" : "%sの命日",
    "Contact birthdays" : "誕生日",
    "Calendar:" : "カレンダー:",
    "Date:" : "日付:",
    "Where:" : "場所:",
    "Description:" : "説明:",
    "Untitled event" : "無題のイベント",
    "_%n year_::_%n years_" : ["%n年"],
    "_%n month_::_%n months_" : ["%nヶ月"],
    "_%n day_::_%n days_" : ["%n日"],
    "_%n hour_::_%n hours_" : ["%n時間"],
    "_%n minute_::_%n minutes_" : ["%n秒"],
    "%s (in %s)" : "%s（%s後）",
    "%s (%s ago)" : "%s（%s前）",
    "Calendar: %s" : "カレンダー:%s",
    "Date: %s" : "日付:%s",
    "Description: %s" : "説明:%s",
    "Where: %s" : "場所:%s",
    "%1$s via %2$s" : "%1$s に %2$s から",
    "Invitation canceled" : "招待のキャンセル",
    "Hello %s," : "%s さん、こんにちは",
    "The meeting »%1$s« with %2$s was canceled." : "会議%1$s « %2$s がキャンセルされました。",
    "Invitation updated" : "招待の更新",
    "The meeting »%1$s« with %2$s was updated." : "会議 %1$s« %2$s が更新されました。",
    "%1$s invited you to »%2$s«" : "%1$s があなたを »%2$s« に招待しました",
    "When:" : "いつ:",
    "Link:" : "リンク:",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "More options …" : "他のオプション …",
    "More options at %s" : "%s のその他のオプション",
    "Contacts" : "アドレス帳",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS / macOSでCalDAVおよびCardDAVを使用するには、%sにHTTPSを設定する必要があります。",
    "Configures a CalDAV account" : "CalDAVアカウントを設定します",
    "Configures a CardDAV account" : "CardDAVアカウントを設定します",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAVエンドポイント",
    "Technical details" : "技術的な詳細",
    "Remote Address: %s" : "リモートアドレス: %s",
    "Request ID: %s" : "リクエスト ID: %s",
    "There was an error updating your attendance status." : "出席状況の更新中にエラーが発生しました。",
    "Please contact the organizer directly." : "主催者に直接お問い合わせください。",
    "Are you accepting the invitation?" : "招待を受け入れていますか？",
    "Tentative" : "暫定的",
    "Save" : "保存",
    "Your attendance was updated successfully." : "出席は正常に更新されました。",
    "Calendar server" : "カレンダーサーバー",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "{calendarappstoreopen}カレンダーアプリ{linkclose}、または{calendardocopen}を同期させるためにデスクトップとモバイルを接続する ↗{linkclose}もインストールしてください。",
    "Send invitations to attendees" : "参加者に招待状を送信する",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen}メールサーバー{linkclose}を正しく設定してください。",
    "Automatically generate a birthday calendar" : "自動的に誕生日カレンダーを生成する",
    "Birthday calendars will be generated by a background job." : "誕生日カレンダーは、バックグラウンドジョブによって生成されます。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "したがって、有効にした直後は利用できませんが、しばらくしてから表示されます。",
    "Send notifications for events" : "イベントの通知を送信",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知はバックグラウンドジョブを介して送信されるため、十分な頻度で発生します。",
    "Enable notifications for events via push" : "イベントのプッシュ通知を有効にする",
    "Please make sure to properly set up the email settings above." : "上記のメール設定を正しく設定してください。",
    "Notifications will be send through background jobs, so these need to happen often enough." : "通知はバックグラウンドジョブを介して送信されるため、十分な頻度で発生します。"
},
"nplurals=1; plural=0;");
